#' DDI4R: A package for working with DDI4 in R.
#'
#' The package provides one R6 class for each class in the DDI4 model.
#' It also contains functions for working with these classes.
#' Some DDI4 classes are intended to be reusable and therefore have a mandatory identifier - a DDI URN.
#' These are referred to here as "identifiable" objects.
#' The DDI Urn is a composite of an Id, a Version, and an Acency. The agency is responsible for ensuring the uniqueness of the Id.
#' DDI4R identifiable objects have a read only active binding "DdiUrn" that returns the DDI URN.
#' When identifiable DDI4R objects are created, a reference from the object's DdiUrn to the object is put in the DDI4R local registry.
#' The R6 object can be found by lookup from this registry. 
#' A second registry allows reverse lookup to find the objects that reference an object. 
#' @section Details:
#' Each R6 class representing a DDI4 class has an active binding for each property and association in the represented DDI4 class.
#' Active bindings act like properties of the object, but can run validation code on assignment.
#' Values for the property or relationship may be set, or retrieved. 
#' Relationships (associations) are represented by a DdiUrn.
#' DDI4R object properties can be categorized into five groups:
#' \itemize{
#'   \item References - A list of DDI URNs pointing to referenced DDI4R objects
#'   \item Simple atomic values - A vector of atomic values (numeric, character, logical, etc)
#'   \item RegularExpression controlled values - A vector of simple atomic values with an associated regular expression for validation
#'   \item Enumeration controlled values - A vector of simple atomic values that must come from a predefined enumeration
#'   \item Structured Datatypes - a list of DDI4R objects. These are not identifiable. They may have multiple properties, including Structured Datatypes.
#' }
#'  
#' @section DDI4R functions:
#' The DDI4R package includes multiple functions for working with DDI4R objects.
#' \itemize{
#'   \item {\code{\link{addToReferencedUrn}}} 		Adds to the dictionary entry of the URNs referencing a referenced URN
#'   \item {\code{\link{ddiObjectFormat}}} 		Format a DDI4 R6 object for print.  (Not Exported)
#'   \item {\code{\link{ddiUrnToName}}} 		Returns a value to be used as a key to register or look up DDI objects 
#'   \item {\code{\link{ddiXmlNodeToObject}}} 		Create a DDI4 R6 object from a DDI4 XML node
#'   \item {\code{\link{deRegisterObject}}} 		Deregisters a list of DDI R6 objects by DDI URN
#'   \item {\code{\link{describeObject}}} 		Generate a script that recreates a DDI4 R6 object
#'   \item {\code{\link{exportObjectXml}}} 		Export a list of Ddi4 objects to XML
#'   \item {\code{\link{getActiveValues}}} 		Get a named vector of the active values of a DDI4 Object
#'   \item {\code{\link{getObject}}} 		Gets DDI object searching the registry for its DDI URN
#'   \item {\code{\link{getObjectFromURL}}} 		Get DDI object by URL
#'   \item {\code{\link{getReferences}}} 		Retrives a list of the association name/URN of the objects referencing the referenced URN
#'   \item {\code{\link{importDdi4XmlFile}}} 		Import A DDI4 XML file into R
#'   \item {\code{\link{insertDdiXmlNode}}} 		Insert a Ddi4 object into an XML Document
#'   \item {\code{\link{is.DDIClass}}} 		Is an object a DDI4 R6 Class Generator?
#'   \item {\code{\link{is.DDIClassName}}} 		Is a name the name of a DDI4 R6 Class?
#'   \item {\code{\link{is.DDIObject}}} 		Is an object a DDI4 R6 Object?
#'   \item {\code{\link{is.anySentinel}}} 		Returns TRUE if any value in a vector is NA or NaN. Also returns TRUE if the length of the vector is 0 or the vector is NULL
#'   \item {\code{\link{isDdiUrnRegistered}}} 		Checks if DDI URN is registered
#'   \item {\code{\link{isSingleString}}} 		Check if a vector is a single string (Not Exported)
#'   \item {\code{\link{listDdiUrn}}} 		Lists registered DDI URNs
#'   \item {\code{\link{listDdiUuid}}} 		Lists registered DDI UUIDs
#'   \item {\code{\link{listReferencedDdiUrns}}} 		Lists the DdiUrns of all of the referenced objects
#'   \item {\code{\link{loadDdi}}} 		Loads saved copies of DDI objects into the DDI4 object registries
#'   \item {\code{\link{makeDdiUrn}}} 		Make a DDI URN from agency, id and version
#'   \item {\code{\link{nameToDdiUrn}}} 		Returns a vector with a  DDIURN or a UUID from a nameVector used as an objectKey in ddi.env.urn 
#'   \item {\code{\link{normalizeDdiUrn}}} 		Normalize DDI URN
#'   \item {\code{\link{parseDdiUrn}}} 		Parse a DDI URN into a named vector
#'   \item {\code{\link{printDdiObject}}} 		Prints a DDI4 Object, with various display options
#'   \item {\code{\link{quoteBackslashEscape}}} 		Quote the quote and backslash characters for inclusion if a quoted string in a script.  (Not Exported)
#'   \item {\code{\link{registerAllDdiObjects}}} 		Register all DDI R6 objects in the listed environment
#'   \item {\code{\link{registerObject}}} 		Registers a DDI R6 object by DDI URN
#'   \item {\code{\link{removeReferencedUrn}}} 		Removes the entry for a referenced URN 
#'   \item {\code{\link{removeReferencingUrn}}} 		Removes one referencing vector from the entry for the referenced URN 
#'   \item {\code{\link{resolveDdiUrn}}} 		Resolve DDI URN to URL
#'   \item {\code{\link{returnEnumeratedValues}}} 		Return a character vector if all of the elements validate against an Enumeration Object
#'   \item {\code{\link{returnR6ObjectIfValid}}} 		Return a list of objects of the specified R6 class, otherwise stops with an error message
#'   \item {\code{\link{returnRegularExpressionValues}}} 		Return a character vector if all of the elements validate against a regular expression Object
#'   \item {\code{\link{returnUrnVectorIfValid}}} 		Return a vector of URNs for objects of the specified R6 class, otherwise stops with an error message
#'   \item {\code{\link{returnVectorIfValid}}} 		Return a vector of primitive values of the specified type, otherwise stops with an error message.
#'   \item {\code{\link{saveDdi}}} 		Save the registries of DDI objects
#'   \item {\code{\link{validateObjectReferences}}} 		Validate a DDI4 Object
#'   \item {\code{\link{validateRegistry}}} 		Validates the references of all objects in the Registry
#' }
#' 
#'
#' @section DDI4 Class List:
#' Here is a list of DDI4R classes:
#' \itemize{
#'   \item {\code{\link{DDI4_Access}}} 		Describes access to the annotated object
#'   \item {\code{\link{DDI4_AccessLocation}}} 		A set of access information for a Machine including URI, mime type, and physical location
#'   \item {\code{\link{DDI4_Act}}} 		An Act is an indivisible, atomic step, i
#'   \item {\code{\link{DDI4_Address}}} 		Location address identifying each part of the address as separate elements, identifying the type of address, the level of privacy associated with the release of the address, and a flag to identify the preferred address for contact
#'   \item {\code{\link{DDI4_Agent}}} 		An actor that performs a role in relation to a process or product
#'   \item {\code{\link{DDI4_AgentAssociation}}} 		A basic structure for declaring the name of an Agent inline, reference to an Agent, and role specification
#'   \item {\code{\link{DDI4_AgentId}}} 		Persistent identifier for a researcher using a system like ORCID
#'   \item {\code{\link{DDI4_AgentIndicator}}} 		Member Indicator for use with member type Agent
#'   \item {\code{\link{DDI4_AgentListing}}} 		A listing of Agents of any type
#'   \item {\code{\link{DDI4_AgentRelation}}} 		Used to define the relation agents in a hierarchical structure
#'   \item {\code{\link{DDI4_AgentRelationStructure}}} 		Defines the relationships between Agents in a collection
#'   \item {\code{\link{DDI4_Algorithm}}} 		An algorithm is an effective method that can be expressed within a finite amount of space and time and in a well-defined formal language for calculating a function
#'   \item {\code{\link{DDI4_AlgorithmOverview}}} 		High level, descriptive, human informative, algorithm statement used to describe the overall methodology
#'   \item {\code{\link{DDI4_AnnotatedIdentifiable}}} 		Used to identify objects for purposes of internal and/or external referencing
#'   \item {\code{\link{DDI4_Annotation}}} 		Provides annotation information on the object to support citation and crediting of the creator(s) of the object
#'   \item {\code{\link{DDI4_AnnotationDate}}} 		A generic date type for use in Annotation which provides the standard date structure plus a property to define the date type (Publication date,  Accepted date, Copyrighted date, Submitted date, etc
#'   \item {\code{\link{DDI4_AppliedUse}}} 		Links the guidance instructions to specific unit types
#'   \item {\code{\link{DDI4_AreaCoverage}}} 		Use to specify the area of land, water, total or other area coverage in terms of square miles/kilometers or other measure as part of a Geographic Extent
#'   \item {\code{\link{DDI4_AttributeRole}}} 		An AttributeRole identifies one or more InstanceVariables as being attributes within a ViewPoint
#'   \item {\code{\link{DDI4_AudioSegment}}} 		Describes the type and length of the audio segment
#'   \item {\code{\link{DDI4_AuthorizationSource}}} 		Identifies the authorizing agency and allows for the full text of the authorization (law, regulation, or other form of authorization)
#'   \item {\code{\link{DDI4_BasedOnObjectInformation}}} 		Use when creating an object that is based on an existing object or objects that are managed by a different agency or when the new object is NOT simply a version change but you wish to maintain a reference to the object that served as a basis for the new object
#'   \item {\code{\link{DDI4_BibliographicName}}} 		Personal names should be listed surname or family name first, followed by forename or given name
#'   \item {\code{\link{DDI4_Binding}}} 		Binds two parameters together to direct flow of data through a process
#'   \item {\code{\link{DDI4_BooleanResponseDomain}}} 		A response domain capturing a binary response, such as selected/unselected or checked/unchecked or true/false
#'   \item {\code{\link{DDI4_BoundingBox}}} 		A type of Spatial coverage describing a rectangular area within which the actual range of location fits
#'   \item {\code{\link{DDI4_Budget}}} 		A description of the budget for any of the main publication types that can contain a reference to an external budget document
#'   \item {\code{\link{DDI4_BusinessAlgorithm}}} 		A Business Algorithm is used to express the generalized function of the Business Process
#'   \item {\code{\link{DDI4_BusinessFunction}}} 		Something an enterprise does, or needs to do, in order to achieve its objectives
#'   \item {\code{\link{DDI4_BusinessProcess}}} 		BusinessProcesses could be Generic Longitudinal Business Process Model (GLBPM) and/or Generic Statistical Business Process Model (GSBPM) steps and/or sub-steps
#'   \item {\code{\link{DDI4_BusinessProcessCondition}}} 		A BusinessProcess precondition or post condition which describes the condition which must be met to begin (pre) or exit (post) a process
#'   \item {\code{\link{DDI4_BusinessProcessIndicator}}} 		Allows for the identification of the BusinessProcess specifically as a member and optionally provides an index for the member within an ordered array
#'   \item {\code{\link{DDI4_Capture}}} 		A measurement that describes a means of capturing data
#'   \item {\code{\link{DDI4_Category}}} 		A Concept whose role is to define and measure a characteristic
#'   \item {\code{\link{DDI4_CategoryIndicator}}} 		Member Indicator for use when the member type is restricted to Category
#'   \item {\code{\link{DDI4_CategoryRelation}}} 		Source target relationship between categories in a classification relation structure
#'   \item {\code{\link{DDI4_CategoryRelationCode}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_CategoryRelationStructure}}} 		Relation structure of categories within a collection
#'   \item {\code{\link{DDI4_CategorySet}}} 		Specialization of a Concept System focusing on sets of categories used as specifications for a generalized concept
#'   \item {\code{\link{DDI4_CategoryStatistic}}} 		Statistics related to a specific category of an InstanceVariable within a data set
#'   \item {\code{\link{DDI4_Char}}} 		a regular expression class.
#'   \item {\code{\link{DDI4_CharacterOffset}}} 		Specification of the character offset for the beginning and end of the segment, or beginning and length
#'   \item {\code{\link{DDI4_ClassificationFamily}}} 		A Classification Family is a collection of Classification Series related from a particular point of view
#'   \item {\code{\link{DDI4_ClassificationIndex}}} 		A Classification Index is an ordered list (alphabetical, in code order etc) of Classification Index Entries
#'   \item {\code{\link{DDI4_ClassificationIndexEntry}}} 		A Classification Index Entry is a word or a short text (e
#'   \item {\code{\link{DDI4_ClassificationIndexEntryIndicator}}} 		Member Indicator for use with member type ClassificationIndexEntry
#'   \item {\code{\link{DDI4_ClassificationItem}}} 		A Classification Item represents a Category at a certain Level within a Statistical Classification
#'   \item {\code{\link{DDI4_ClassificationItemIndicator}}} 		A ClassificationItemIndicator realizes and extends a MemberIndicator which provides a Classification Item with an index indicating order and a level reference providing the level location of the Classification Item within a hierarchical structure
#'   \item {\code{\link{DDI4_ClassificationItemRelation}}} 		Source target relationship between classification items in a classification item relation structure
#'   \item {\code{\link{DDI4_ClassificationItemRelationStructure}}} 		A complex RelationStructure for use with statistical classification
#'   \item {\code{\link{DDI4_ClassificationSeries}}} 		A Classification Series is an ensemble of one or more Statistical Classifications, based on the same concept, as documented by the definingConcept relationship, and related to each other as versions or updates
#'   \item {\code{\link{DDI4_ClassificationSeriesIndicator}}} 		Member Indicator for use with member type ClassificationSeries
#'   \item {\code{\link{DDI4_ClassificationSeriesRelation}}} 		Defines the Classification Series in a complex relation and specifies the relationshi
#'   \item {\code{\link{DDI4_ClassificationSeriesRelationStructure}}} 		Describes the complex relation structure of a classification family
#'   \item {\code{\link{DDI4_Code}}} 		A type of Designation that relates a representation expressed as a string with or without meaningful white space to a specific classification
#'   \item {\code{\link{DDI4_CodeIndicator}}} 		A CodeIndicator realizes and extends a MemberIndicator which provides a Code with an index indicating order and a level reference providing the level location of the Code within a hierarchical structure
#'   \item {\code{\link{DDI4_CodeList}}} 		A list of Codes and associated Categories
#'   \item {\code{\link{DDI4_CodeListResponseDomain}}} 		A response domain capturing a coded response (where both codes and their related category value are displayed) for a question
#'   \item {\code{\link{DDI4_CodeRelation}}} 		Source target relationship between codes in a code relation structure
#'   \item {\code{\link{DDI4_CodeRelationStructure}}} 		Relation structure of codes within a codelist
#'   \item {\code{\link{DDI4_CollectionMember}}} 		Generic class representing members of a collection
#'   \item {\code{\link{DDI4_CollectionType}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_Command}}} 		Provides the following information on the command
#'   \item {\code{\link{DDI4_CommandCode}}} 		Contains information on the command used for processing data
#'   \item {\code{\link{DDI4_CommandFile}}} 		Identifies and provides a link to an external copy of the command, for example, a SAS Command Code script
#'   \item {\code{\link{DDI4_Comparison}}} 		The minimal pattern for a comparison including a mapping between members
#'   \item {\code{\link{DDI4_ComparisonMap}}} 		Provides a basic pattern for a comparison map which identifies source and target members and details about their match
#'   \item {\code{\link{DDI4_ComplianceStatement}}} 		Allows for a quality statement based on frameworks to be described using itemized properties
#'   \item {\code{\link{DDI4_ComputationAction}}} 		Provides an extensible framework for specific computation or transformation objects
#'   \item {\code{\link{DDI4_ComputationBaseList}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_Concept}}} 		Unit of thought differentiated by characteristics [GSIM 1
#'   \item {\code{\link{DDI4_ConceptIndicator}}} 		Member Indicator for use with member type Concept and all subtypes of Concept: Category, Universe, Population, Unit Type
#'   \item {\code{\link{DDI4_ConceptRelation}}} 		Specifies the relationship between concepts in a collection of concepts
#'   \item {\code{\link{DDI4_ConceptRelationStructure}}} 		Relation structure of concepts within a collection
#'   \item {\code{\link{DDI4_ConceptSystem}}} 		A set of Concepts structured by the relations among them
#'   \item {\code{\link{DDI4_ConceptSystemCorrespondence}}} 		Relationship between 2 or more ConceptSystems described through mapping similarity relationships between their member Concepts
#'   \item {\code{\link{DDI4_ConceptualDomain}}} 		Set of Concepts, both sentinel and substantive, that can be described by either enumeration or by an expression
#'   \item {\code{\link{DDI4_ConceptualInstrument}}} 		Design plan for creating a data capture tool
#'   \item {\code{\link{DDI4_ConceptualVariable}}} 		The use of a Concept as a characteristic of a UnitType intended to be measured
#'   \item {\code{\link{DDI4_ConditionalControlStep}}} 		Type of WorkflowControlStep in which the execution flow is determined by one or more conditions
#'   \item {\code{\link{DDI4_ConditionalText}}} 		Text which has a changeable value depending on a stated condition, response to earlier questions, or as input from a set of metrics (pre-supplied data)
#'   \item {\code{\link{DDI4_ContactInformation}}} 		Contact information for the individual or organization including location specification, address, web site, phone numbers, and other means of communication access
#'   \item {\code{\link{DDI4_ContentDateOffset}}} 		Identifies the difference between the date applied to the data as a whole and this specific item such as previous year's income or residence 5 years ago
#'   \item {\code{\link{DDI4_ControlledVocabulary}}} 		The specification of a controlled vocabulary defines a set of values and their definitions together with the order relationships among those entries
#'   \item {\code{\link{DDI4_CorrespondenceTable}}} 		A Correspondence Table expresses relationships between the members within or between StatisticalClassifications
#'   \item {\code{\link{DDI4_CorrespondenceType}}} 		Describes the commonalities and differences between two members using a textual description of both commonalities and differences plus an optional coding of the type of commonality
#'   \item {\code{\link{DDI4_Coverage}}} 		Coverage information for an annotated object
#'   \item {\code{\link{DDI4_CustomInstance}}} 		A set of CustomValues to be attached to some object
#'   \item {\code{\link{DDI4_CustomItem}}} 		A custom item description
#'   \item {\code{\link{DDI4_CustomItemIndicator}}} 		Member Indicator for use with member type CustomItem
#'   \item {\code{\link{DDI4_CustomItemRelation}}} 		Defines a relationship between CustomItems 
#'   \item {\code{\link{DDI4_CustomItemRelationStructure}}} 		Contains a set of CustomItemRelations which together define the relationships of Custom Structure
#'   \item {\code{\link{DDI4_CustomStructure}}} 		A Collection containing a set of item descriptions defining a structure for a set of key,value pairs
#'   \item {\code{\link{DDI4_CustomValue}}} 		An instance of a  key, value pair for a  particular  key
#'   \item {\code{\link{DDI4_CustomValueIndicator}}} 		Member Indicator for use with member type CustomValue
#'   \item {\code{\link{DDI4_DataPipeline}}} 		A DataPipeline is a single traversal of the Generic Longitudinal Business Model (GLBPM) and/or the Generic Statistical Business process Model (GSBPM) in the course of a study where a study is either one off or a wave in a StudySeries
#'   \item {\code{\link{DDI4_DataPoint}}} 		A DataPoint is a container for a Datum
#'   \item {\code{\link{DDI4_DataPointIndicator}}} 		Member Indicator for use with member type DataPoint
#'   \item {\code{\link{DDI4_DataPointRelation}}} 		Data Point relations used by the Data Point Relation Structure of a Logical Record to describe specific source target Data Points and their relationship
#'   \item {\code{\link{DDI4_DataPointRelationStructure}}} 		A means for describing the complex relational structure of Data Points in a Logical Record 
#'   \item {\code{\link{DDI4_DataStore}}} 		A DataStore is either a SimpleCollection or a StructuredCollection of LogicalRecords, keeping in mind that a LogicalRecords is a definition, not a "datasets"
#'   \item {\code{\link{DDI4_DataStoreIndicator}}} 		Member Indicator for use with member type DataStore
#'   \item {\code{\link{DDI4_DataStoreLibrary}}} 		A DataStoreLibrary is a collection or, again, a "library" of DataStores
#'   \item {\code{\link{DDI4_DataStoreRelation}}} 		Defines the complex relationship between 2 or more DataStores in a DataLibrary
#'   \item {\code{\link{DDI4_DataStoreRelationStructure}}} 		A structure for describing a complex relation of DataStores within a DataStoreLibrary
#'   \item {\code{\link{DDI4_Date}}} 		Provides the structure of a single Date expressed in an ISO date structure along with equivalent expression in any number of non-ISO formats
#'   \item {\code{\link{DDI4_DateRange}}} 		Expresses a date/time range using a start date and end date (both with the structure of Date and supporting the use of ISO and non-ISO date structures)
#'   \item {\code{\link{DDI4_Datum}}} 		A Datum is a designation (a representation of a concept by a sign) with a notion of equality defined
#'   \item {\code{\link{DDI4_Design}}} 		The design pattern class may be used to specify or, again, defines how a process will be performed in general
#'   \item {\code{\link{DDI4_DesignOverview}}} 		High level, descriptive, human informative, design statement The design may be used to specify how a process will be performed in general
#'   \item {\code{\link{DDI4_Designation}}} 		A sign denoting a concept
#'   \item {\code{\link{DDI4_DocumentInformation}}} 		Provides a consistent path to identifying information regarding the DDI Document and is automatically available for all Functional Views (/DocumentInformation/Annotation etc
#'   \item {\code{\link{DDI4_DoubleNumberRangeValue}}} 		Describes a bounding value for a number range expressed as an xs:double
#'   \item {\code{\link{DDI4_DynamicText}}} 		Structure supporting the use of dynamic text, where portions of the textual content change depending on external information (pre-loaded data, response to an earlier query, environmental situations, etc
#'   \item {\code{\link{DDI4_DynamicTextContent}}} 		Abstract type existing as the head of a substitution group
#'   \item {\code{\link{DDI4_ElectronicMessageSystem}}} 		Any non-email means of relaying a message electronically
#'   \item {\code{\link{DDI4_ElseIfAction}}} 		An additional condition and resulting step to take if the condition in the parent IfThenElse is false
#'   \item {\code{\link{DDI4_Email}}} 		An e-mail address which conforms to the internet format (RFC 822) including its type and time period for which it is valid
#'   \item {\code{\link{DDI4_Embargo}}} 		Provides information about data that are not currently available because of policies established by the principal investigators and/or data producers
#'   \item {\code{\link{DDI4_EnumerationDomain}}} 		An abstract base to allow all codifications (CodeList, StatisticalClassification, etc
#'   \item {\code{\link{DDI4_ExPostEvaluation}}} 		Evaluation for the purpose of reviewing the study, data collection, data processing, or management processes
#'   \item {\code{\link{DDI4_ExternalAid}}} 		Any external material used in an instrument that aids or facilitates data capture, or that is presented to a respondent and about which measurements are made
#'   \item {\code{\link{DDI4_ExternalControlledVocabularyEntry}}} 		Allows for unstructured content which may be an entry from an externally maintained controlled vocabulary
#'   \item {\code{\link{DDI4_ExternalMaterial}}} 		ExternalMaterial describes the location, structure, and relationship to the DDI metadata instance for any material held external to that instance
#'   \item {\code{\link{DDI4_FixedText}}} 		The static portion of the text expressed as a StructuredString with the ability to preserve whitespace if critical to the understanding of the content
#'   \item {\code{\link{DDI4_Form}}} 		A link to a form used by the metadata containing the form number, a statement regarding the contents of the form, a statement as to the mandatory nature of the form and a privacy level designation
#'   \item {\code{\link{DDI4_FundingInformation}}} 		Provides information about the individual, agency and/or grant(s) which funded the described entity
#'   \item {\code{\link{DDI4_GeographicExtent}}} 		Defines the extent of a geographic unit for a specified period of time using Bounding Box, Inclusive and Exclusive Polygons, and an area coverage that notes a type of coverage (land, water, etc
#'   \item {\code{\link{DDI4_GeographicUnit}}} 		A specific geographic unit of a defined Unit Type
#'   \item {\code{\link{DDI4_GeographicUnitClassification}}} 		Describes the classification of specific geographic units into a classification system
#'   \item {\code{\link{DDI4_GeographicUnitIndicator}}} 		Provides ability to declare an optional sequence or index order to a Geographic Unit
#'   \item {\code{\link{DDI4_GeographicUnitRelation}}} 		Describes structured relationship between Geographic Units
#'   \item {\code{\link{DDI4_GeographicUnitRelationStructure}}} 		Defines the relationships between Geographic Unit Types in a collection
#'   \item {\code{\link{DDI4_GeographicUnitTypeClassification}}} 		A structured collection of Unit Types defining a geographic structure
#'   \item {\code{\link{DDI4_GeographicUnitTypeIndicator}}} 		Provides ability to declare an optional sequence or index order to a Unit Type describing a Geographic Unit Type
#'   \item {\code{\link{DDI4_GeographicUnitTypeRelation}}} 		Describes structured relationship between Unit Types used to define Geographic Unit Types
#'   \item {\code{\link{DDI4_GeographicUnitTypeRelationStructure}}} 		Defines the relationships between Geographic Unit Types in a collection
#'   \item {\code{\link{DDI4_Goal}}} 		Goals are the "things" a method aims to achieve
#'   \item {\code{\link{DDI4_Guide}}} 		Provides a guide for the usage of a result within a specified application
#'   \item {\code{\link{DDI4_Identifiable}}} 		Used to identify objects for purposes of internal and/or external referencing
#'   \item {\code{\link{DDI4_IdentifierRole}}} 		An IdentifierRole identifies one or more InstanceVariables as being identifiers within a ViewPoint
#'   \item {\code{\link{DDI4_IfThenElse}}} 		IfThenElse describes an if-then-else decision type of control construct
#'   \item {\code{\link{DDI4_Image}}} 		A reference to an image, with a description of its properties and type
#'   \item {\code{\link{DDI4_ImageArea}}} 		Defines the shape and area of an image used as part of a location representation
#'   \item {\code{\link{DDI4_ImplementedInstrument}}} 		A specific data capture tool
#'   \item {\code{\link{DDI4_IndexEntryRelation}}} 		Relationship between Index Entries defined by RelationSpecification
#'   \item {\code{\link{DDI4_IndexEntryRelationStructure}}} 		Structures relationship of Classification Index Entries in a Classification Index
#'   \item {\code{\link{DDI4_Individual}}} 		A person who may have a relationship to another Agent and who may be specified as being associated with an act
#'   \item {\code{\link{DDI4_IndividualName}}} 		The name of an individual broken out into its component parts of prefix, first/given name, middle name, last/family/surname, and suffix
#'   \item {\code{\link{DDI4_InstanceMeasurement}}} 		An instance measurement instantiates a represented measurement, so that it can be used as an Act in the Process Steps that define a data capture process
#'   \item {\code{\link{DDI4_InstanceQuestion}}} 		An instance question is an instantiation of a represented question,to be used as an Act in the process steps that define a survey questionnaire
#'   \item {\code{\link{DDI4_InstanceVariable}}} 		The use of a Represented Variable within a Data Set
#'   \item {\code{\link{DDI4_InstanceVariableIndicator}}} 		Allows for the identification of the InstanceVariable specifically as a member and optionally provides an index for the member within an ordered array
#'   \item {\code{\link{DDI4_InstanceVariableRelation}}} 		Defines the relationship between 2 or more InstanceVariables
#'   \item {\code{\link{DDI4_InstanceVariableRelationStructure}}} 		A realization of RelationStructure that is used to describe the order of InstanceVariables in a record for those cases where the variables have a more complicated logical order than a simple sequence
#'   \item {\code{\link{DDI4_InstanceVariableValueMap}}} 		A key value relationship for two or more logical records where the key is one or more equivalent instance variables and the value is a defined relationship or a relationship to a set value
#'   \item {\code{\link{DDI4_Instruction}}} 		Provides the content and description of data capture instructions
#'   \item {\code{\link{DDI4_InstrumentCode}}} 		An InstrumentComponent that specifies the performance of a specific computation within the context of an instrument flow
#'   \item {\code{\link{DDI4_InstrumentComponent}}} 		InstrumentComponent is an abstract object which extends an Act (a type of Process Step)
#'   \item {\code{\link{DDI4_InternationalIdentifier}}} 		An identifier whose scope of uniqueness is broader than the local archive
#'   \item {\code{\link{DDI4_InternationalString}}} 		Packaging structure for multiple language versions of the same string content
#'   \item {\code{\link{DDI4_InternationalStructuredString}}} 		Packaging structure for multiple language versions of the same string content, for objects that allow for internal formatting using XHTML tags
#'   \item {\code{\link{DDI4_IsoDateType}}} 		a regular expression class.
#'   \item {\code{\link{DDI4_LabelForDisplay}}} 		A structured display label
#'   \item {\code{\link{DDI4_LanguageSpecificStringType}}} 		Allows for non-formatted language specific strings that may be translations from other languages, or that may be translatable into other languages
#'   \item {\code{\link{DDI4_LanguageSpecificStructuredStringType}}} 		Supports the optional use of formatting tags expressed with escape characters within the string structure
#'   \item {\code{\link{DDI4_Level}}} 		Provides Level information for the members of the LevelStructure
#'   \item {\code{\link{DDI4_LevelStructure}}} 		The LevelStructure describes the nesting structure of a hierarchical collection
#'   \item {\code{\link{DDI4_LineParameter}}} 		Specification of the line and offset for the beginning and end of the segment
#'   \item {\code{\link{DDI4_LiteralText}}} 		Literal (static) text to be used in an instrument
#'   \item {\code{\link{DDI4_LocalIdFormat}}} 		This is an identifier in a given local context that uniquely references an object, as opposed to the full ddi identifier which has an agency plus the id
#'   \item {\code{\link{DDI4_LocationName}}} 		Name of the location using the DDI Name structure and the ability to add an effective date
#'   \item {\code{\link{DDI4_LogicalRecord}}} 		The LogicalRecord is a record definition
#'   \item {\code{\link{DDI4_LogicalRecordIndicator}}} 		Member Indicator for use with member type LogicalRecord
#'   \item {\code{\link{DDI4_LogicalRecordRelation}}} 		Defines complex relationship between LogicalRecords
#'   \item {\code{\link{DDI4_LogicalRecordRelationStructure}}} 		Allows for the complex structuring of relationships between LogicalRecords in a DataStore
#'   \item {\code{\link{DDI4_Loop}}} 		Iterative control structure to be repeated a specified number of times based on one or more conditions
#'   \item {\code{\link{DDI4_Machine}}} 		Mechanism or computer program used to implement a process
#'   \item {\code{\link{DDI4_Map}}} 		Describes the correspondence between concepts in a correspondence table related to one or more Statistical Classifications
#'   \item {\code{\link{DDI4_MappingRelation}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_MeasureRole}}} 		A MeasureRole identifies one or more InstanceVariables as being measures within a ViewPoint
#'   \item {\code{\link{DDI4_MemberIndicator}}} 		Provides ability to declare an optional sequence or index order to a CollectionMember
#'   \item {\code{\link{DDI4_MemberRelation}}} 		Defines one kind of relationship between one member (source) and possibly several members (target)
#'   \item {\code{\link{DDI4_MetadataDrivenAction}}} 		MetadataDrivenActions are Acts in which their logic is defined by validation and transformation rules expressed in some standard rule language
#'   \item {\code{\link{DDI4_Methodology}}} 		Methodology brings together the design, algorithm, and process as a logically structured approach to an activity such as sampling, weighting, harmonization, imputation, collection management, etc
#'   \item {\code{\link{DDI4_MethodologyOverview}}} 		High level, descriptive, human informative methodology statement used to describe the overall methodology, identify related design, algorithm, and process information
#'   \item {\code{\link{DDI4_NonIsoDateType}}} 		Used to preserve an historical date, formatted in a non-ISO fashion
#'   \item {\code{\link{DDI4_NumberRange}}} 		Structures a numeric range
#'   \item {\code{\link{DDI4_NumberRangeValue}}} 		Describes a bounding value for a number range expressed as an xs:demical
#'   \item {\code{\link{DDI4_NumericResponseDomain}}} 		A response domain capturing a numeric response (the intent is to analyze the response as a number) for a question
#'   \item {\code{\link{DDI4_ObjectName}}} 		A standard means of expressing a Name for a class object
#'   \item {\code{\link{DDI4_Organization}}} 		A framework of authority designated to act toward some purpose
#'   \item {\code{\link{DDI4_OrganizationName}}} 		Names by which the organization is known
#'   \item {\code{\link{DDI4_PairedExternalControlledVocabularyEntry}}} 		A tightly bound pair of items from an external controlled vocabulary
#'   \item {\code{\link{DDI4_Parameter}}} 		An Input or Output to a Process Step defined by as a unique identifier
#'   \item {\code{\link{DDI4_PhysicalDataSet}}} 		The information needed for understanding the physical structure of data coming from a file or other source
#'   \item {\code{\link{DDI4_PhysicalLayoutRelationStructure}}} 		A realization of RelationStructure that is used to describe the sequence of Value Mappings in a Physical Layout
#'   \item {\code{\link{DDI4_PhysicalOrderRelationStructure}}} 		PhysicalStructureOrder orders thePhysicalRecordSegments  which map to a LogicalRecord
#'   \item {\code{\link{DDI4_PhysicalRecordSegment}}} 		A description of each physical storage segment required to completely cover the logical record
#'   \item {\code{\link{DDI4_PhysicalRecordSegmentIndicator}}} 		Member Indicator for use with member type PhysicalRecordSegment
#'   \item {\code{\link{DDI4_PhysicalRecordSegmentRelation}}} 		Defines structured relationship between PhysicalRecordSegments
#'   \item {\code{\link{DDI4_PhysicalSegmentLayout}}} 		The PhysicalSegmentLayout is an abstract class used as an extension point in the description of the different layout styles of data structure description
#'   \item {\code{\link{DDI4_PhysicalSegmentLocation}}} 		Among other things defines the location of a DataPoint in a PhysicalSegment (e
#'   \item {\code{\link{DDI4_PointFormat}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_Polygon}}} 		A closed plane figure bounded by three or more line segments, representing a geographic area
#'   \item {\code{\link{DDI4_Population}}} 		Set of specific units (people, entities, objects, events) with specification of time and geography
#'   \item {\code{\link{DDI4_Precondition}}} 		A precondition is a state
#'   \item {\code{\link{DDI4_PrivateImage}}} 		References an image using the standard Image description
#'   \item {\code{\link{DDI4_Process}}} 		Process is an implementation of an algorithm
#'   \item {\code{\link{DDI4_ProcessControlStep}}} 		A Process Step that controls the ordering of execution for one or more Process Steps
#'   \item {\code{\link{DDI4_ProcessOverview}}} 		Process is an implementation of an algorithm
#'   \item {\code{\link{DDI4_ProcessStep}}} 		One of the constituents of a Process
#'   \item {\code{\link{DDI4_QualityStatement}}} 		A statement of quality which may be related to an external standard or contain a simple overview, rationale, and usage statement
#'   \item {\code{\link{DDI4_RangeValue}}} 		Describes a bounding value of a string
#'   \item {\code{\link{DDI4_RankingResponseDomain}}} 		A response domain capturing a ranking response which supports a "ranking" or "Ordering" of provided categories
#'   \item {\code{\link{DDI4_RationaleDefinition}}} 		Textual description of the rationale/purpose for the version change and a coded value to provide an internal processing flag within and organization or system
#'   \item {\code{\link{DDI4_RecordRelation}}} 		The RecordRelation object is used to indicate relationships among record types within and between LogicalRecords
#'   \item {\code{\link{DDI4_ReferenceDate}}} 		The date covered by the annotated object
#'   \item {\code{\link{DDI4_RelationSpecification}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_RelationStructure}}} 		The set of MemberRelations used to structure a Collection
#'   \item {\code{\link{DDI4_RepeatUntil}}} 		Iterative control structure to be repeated until a specified condition is met
#'   \item {\code{\link{DDI4_RepeatWhile}}} 		Iterative control structure to be repeated while a specified condition is met
#'   \item {\code{\link{DDI4_RepresentedMeasurement}}} 		The description of a reusable non-question measurement that can be used as a template that describes the components of a measurement
#'   \item {\code{\link{DDI4_RepresentedQuestion}}} 		The description of a reusable question, that can be used as a template that describes the components of a question
#'   \item {\code{\link{DDI4_RepresentedVariable}}} 		A combination of a characteristic of a universe to be measured and how that measure will be represented
#'   \item {\code{\link{DDI4_ResourceIdentifier}}} 		Provides a means of identifying a related resource and provides the typeOfRelationship
#'   \item {\code{\link{DDI4_ResponseDomain}}} 		The possible list of values that are allowed by a Capture
#'   \item {\code{\link{DDI4_Result}}} 		Describes the results of a process for the purpose of linking these results to guidance for future usage in specified situations
#'   \item {\code{\link{DDI4_SampleFrame}}} 		A set of information used to identify a sample population within a larger population
#'   \item {\code{\link{DDI4_SamplePopulationResult}}} 		The Sample Population is the result of a sampling process
#'   \item {\code{\link{DDI4_SamplingAlgorithm}}} 		Generic description of a sampling algorithm expressed by a Sampling Design and implemented by a Sampling Process
#'   \item {\code{\link{DDI4_SamplingDesign}}} 		Sampling plan defines the how the sample is to be obtained through the description of methodology or a model based approach, defining the intended target population, stratification or split procedures and recommended sample frames
#'   \item {\code{\link{DDI4_SamplingGoal}}} 		Provides general description and specific targets for sample sizes including sub-populations
#'   \item {\code{\link{DDI4_SamplingProcedure}}} 		The Sampling Procedure describes the population being sampled, the sampling frame and the sampling plan including steps and sub steps by referencing the universe, sample frames and sampling plans described in schemes
#'   \item {\code{\link{DDI4_SamplingProcess}}} 		Provides the details of the process used to apply the sampling design and obtain the sample
#'   \item {\code{\link{DDI4_ScaleResponseDomain}}} 		A response domain capturing a scaled response, such as a Likert scale
#'   \item {\code{\link{DDI4_Segment}}} 		A structure used to express explicit segments or regions within different types of external materials (Textual, Audio, Video, XML, and Image)
#'   \item {\code{\link{DDI4_SegmentByText}}} 		Defines the location of a segment of text through character, and optionally line, counts
#'   \item {\code{\link{DDI4_SentinelConceptualDomain}}} 		Description or list of possible sentinel concepts , e
#'   \item {\code{\link{DDI4_SentinelValueDomain}}} 		The Value Domain for a sentinel conceptual domain
#'   \item {\code{\link{DDI4_Service}}} 		A means of performing a Process Step as part of a Business Function (an ability that an organization possesses, typically expressed in general and high level terms and requiring a combination of organization, people, processes and technology to achieve)
#'   \item {\code{\link{DDI4_SexSpecificationType}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_ShapeCoded}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_Sign}}} 		Something that suggests the presence or existence of a fact, condition, or quality
#'   \item {\code{\link{DDI4_Signified}}} 		Concept or object denoted by the signifier associated to a sign
#'   \item {\code{\link{DDI4_Signifier}}} 		Concept whose extension includes perceivable objects
#'   \item {\code{\link{DDI4_SimpleCollection}}} 		Simple Collection container (set or bag) that may be unordered or ordered using Member Indicator
#'   \item {\code{\link{DDI4_SpatialCoordinate}}} 		Lists the value and format type for the coordinate value
#'   \item {\code{\link{DDI4_SpatialCoverage}}} 		A description of spatial coverage (geographic coverage) of the annotated object
#'   \item {\code{\link{DDI4_SpatialLine}}} 		Defines a geographic line (minimum of 2 points)
#'   \item {\code{\link{DDI4_SpatialObjectPairs}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_SpatialObjectType}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_SpatialPoint}}} 		A geographic point consisting of an X and Y coordinate
#'   \item {\code{\link{DDI4_SpatialRelationSpecification}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_SpatialRelationship}}} 		Used to specify a relationship between one spatial object and another
#'   \item {\code{\link{DDI4_Split}}} 		The components of a Split consists of a number of process steps to be executed concurrently with partial synchronization
#'   \item {\code{\link{DDI4_SplitJoin}}} 		SplitJoin consists of process steps that are executed concurrently (execution with barrier synchronization)
#'   \item {\code{\link{DDI4_Standard}}} 		Identifies the external standard used and describes the level of compliance with the standard in terms specific aspects of the standard's content
#'   \item {\code{\link{DDI4_StandardWeight}}} 		Provides an identified value for a standard weight expressed as an xs:float
#'   \item {\code{\link{DDI4_Statement}}} 		A Statement is a type of Instrument Component containing  human readable text or referred material
#'   \item {\code{\link{DDI4_Statistic}}} 		The value of the statistic expressed as an xs:decimal and/or xs:double
#'   \item {\code{\link{DDI4_StatisticalClassification}}} 		A Statistical Classification is a set of Categories represented by Classification Items which may be assigned to one or more variables registered in statistical surveys or administrative files, and used in the production and dissemination of statistics
#'   \item {\code{\link{DDI4_StatisticalClassificationIndicator}}} 		Member Indicator for use with member type StatisticalClassification
#'   \item {\code{\link{DDI4_StatisticalClassificationRelation}}} 		Specifies the Statistical Classifications for the source and target of the complex relationship and defines the relationship
#'   \item {\code{\link{DDI4_StatisticalClassificationRelationStructure}}} 		A structure for describing the complex relationship between statistical classifications in a classification series
#'   \item {\code{\link{DDI4_StringStructureType}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_StructuredCollection}}} 		Structured Collection container extends a Simple Collection allowing it to optionally have an RelationshpStructure to model hierarchies and nesting or more complex network structures
#'   \item {\code{\link{DDI4_Study}}} 		Study is the conceptual anchor for an individual collection activity resulting in a data set or data file
#'   \item {\code{\link{DDI4_StudyControl}}} 		StudyControl references a Study
#'   \item {\code{\link{DDI4_StudyIndicator}}} 		Member Indicator for use with member type Study
#'   \item {\code{\link{DDI4_StudyRelation}}} 		Relation specification between source and target studies in a relation structure
#'   \item {\code{\link{DDI4_StudyRelationStructure}}} 		Allows for a complex nested structure for a Study Series
#'   \item {\code{\link{DDI4_StudySeries}}} 		A collection of studies which can be structured as a simple sequence, or with a more complex structure
#'   \item {\code{\link{DDI4_SubstantiveConceptualDomain}}} 		Set of valid Concepts
#'   \item {\code{\link{DDI4_SubstantiveValueDomain}}} 		The Value Domain for a substantive conceptual domain
#'   \item {\code{\link{DDI4_SummaryStatistic}}} 		Describes summary statistics for a variable
#'   \item {\code{\link{DDI4_TableDirectionValues}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_TargetSample}}} 		Specifies details of target sample size, percentage, type, and universe
#'   \item {\code{\link{DDI4_Telephone}}} 		Details of a telephone number including the number, type of number, a privacy setting and an indication of whether this is the preferred contact number
#'   \item {\code{\link{DDI4_TemporalCoverage}}} 		Describes the temporal coverage of the annotated object by specifying dates and optionally associating them with Subject and Keyword
#'   \item {\code{\link{DDI4_TemporalRelationControlStep}}} 		Defines complex synchronous or asynchronous temporal ordering control
#'   \item {\code{\link{DDI4_TemporalRelationSpecification}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_TextDirectionValues}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_TextResponseDomain}}} 		A response domain capturing a textual response including the length of the text and restriction of content using a regular expression
#'   \item {\code{\link{DDI4_TextualSegment}}} 		Defines the segment of textual content used by the parent object
#'   \item {\code{\link{DDI4_TopicalCoverage}}} 		Describes the topical coverage of the module using Subject and Keyword
#'   \item {\code{\link{DDI4_TotalityType}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_TrimValues}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_TypedDescriptiveText}}} 		This Complex Data Type bundles a descriptiveText with an External Controlled Vocabulary Entry allowing structured content and a means of typing that content
#'   \item {\code{\link{DDI4_TypedString}}} 		TypedString combines a typeOfContent with a content defined as a simple string
#'   \item {\code{\link{DDI4_Unit}}} 		The object of interest in a process step related to the collection or use of observational data
#'   \item {\code{\link{DDI4_UnitDataRecord}}} 		Gives a UnitDataRecord structure to a Logical Record
#'   \item {\code{\link{DDI4_UnitDataViewpoint}}} 		The assignment of measure, identifier and attribute roles to InstanceVariables
#'   \item {\code{\link{DDI4_UnitSegmentLayout}}} 		UnitSegmentLayout supports the description of unit-record ("wide") data sets, where each row in the data set provides the same group of values for variables all relating to a single unit
#'   \item {\code{\link{DDI4_UnitType}}} 		A Unit Type is a type or class of objects of interest
#'   \item {\code{\link{DDI4_Universe}}} 		A defined set or class of people, entities, events, or objects, with no specification of time and geography, contextualizing a Unit Type
#'   \item {\code{\link{DDI4_ValueAndConceptDescription}}} 		A formal description of a set of values
#'   \item {\code{\link{DDI4_ValueDomain}}} 		The permitted range of values for a characteristic of a variable
#'   \item {\code{\link{DDI4_ValueMapping}}} 		Provides physical characteristics for an InstanceVariable as part of a PhysicalSegmentLayout
#'   \item {\code{\link{DDI4_ValueMappingIndicator}}} 		Member Indicator for use with member type ValueMapping
#'   \item {\code{\link{DDI4_ValueMappingRelation}}} 		Variable relationships in PhysicalLayout as defined using ValueMappingRelation
#'   \item {\code{\link{DDI4_ValueRelationshipType}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_ValueString}}} 		The Value expressed as an xs:string with the ability to preserve whitespace if critical to the understanding of the content
#'   \item {\code{\link{DDI4_VariableCollection}}} 		A collection (group) of any type of Variable within the Variable Cascade (Conceptual, Represented, Instance) for purposes of management, conceptualization or anything other than organizing a logical record or physical layout
#'   \item {\code{\link{DDI4_VariableIndicator}}} 		Member Indicator for use with member type ConceptualVariable, RepresentedVariable, and InstanceVariable
#'   \item {\code{\link{DDI4_VariableRelation}}} 		Ordered relations between any Variables in the Variable Cascade (Conceptual, Represented, Instance)
#'   \item {\code{\link{DDI4_VariableRelationStructure}}} 		RelationStructure for use with any mixture of Variables in the Variable Cascade (Conceptual, Represented, Instance)
#'   \item {\code{\link{DDI4_VariableStatistics}}} 		Contains summary and category level statistics for the referenced variable
#'   \item {\code{\link{DDI4_VideoSegment}}} 		Describes the type and length of the video segment
#'   \item {\code{\link{DDI4_ViewpointRole}}} 		A ViewpointRole designates the function an InstanceVariable performs in the context of the Viewpoint
#'   \item {\code{\link{DDI4_VocabularyEntry}}} 		One entry term and its definition in an ordered list comprising a controlled vocabulary
#'   \item {\code{\link{DDI4_VocabularyEntryIndicator}}} 		Member Indicator for use with member type VocabularyEntry
#'   \item {\code{\link{DDI4_VocabularyEntryRelation}}} 		Relation of Vocabulary Entries as defined using RelationSpecification 
#'   \item {\code{\link{DDI4_VocabularyRelationStructure}}} 		Contains the Vocabulary Relations used to structure the ControlledVocabulary
#'   \item {\code{\link{DDI4_WebLink}}} 		A web site (normally a URL) with information on type of site, privacy flag, and effective dates
#'   \item {\code{\link{DDI4_WhiteSpaceRule}}} 		an Enumeration class.
#'   \item {\code{\link{DDI4_WorkflowControlStep}}} 		A subtype of WorkflowStep which controls the ordering of Workflow Steps within a Process
#'   \item {\code{\link{DDI4_WorkflowProcess}}} 		A Workflow Process is a realization of Process which identifies the Workflow Step Sequence which contains the WorkflowSteps and their order
#'   \item {\code{\link{DDI4_WorkflowService}}} 		A means of performing a Workflow Step as part of a concrete implementation of a Business Function  (an ability that an organization possesses, typically expressed in general and high level terms and requiring a combination of organization, people, processes and technology to achieve)
#'   \item {\code{\link{DDI4_WorkflowStep}}} 		One of the constituents of a Workflow
#'   \item {\code{\link{DDI4_WorkflowStepOrder}}} 		Associates an sequence ordering number with any WorflowStep or sub-type,
#'   \item {\code{\link{DDI4_WorkflowStepSequence}}} 		A WorkflowStepSequence controls the order of WorkflowSteps by defining a simple sequence
#' }
#' @docType package
#' @name DDI4R
NULL

